Base schema: None

This is a proposed new schema for flow-cytometry devices.

* Changed mAU unit to second time for vertex document coordinates BENCHLING/2025/03
 * Reasoning: Added for handling cases where coordinates are measured in time units
 * Proposal: change mAU to s